@@ -1,7 +1,6 @@
 #pragma once
 
 #include "../ds/bits.h"
-#include "../mem/allocconfig.h"
 
 #if defined(FreeBSD_KERNEL)
 extern "C"
@@ -29,7 +28,7 @@ namespace snmalloc
      * PAL supports.
      */
     static constexpr uint64_t pal_features = AlignedAllocation;
-    void error(const char* const str)
+    [[noreturn]] void error(const char* const str)
     {
       panic("snmalloc error: %s", str);
     }
